Description Usage Arguments Examples
* '.R': extracts requirements from parsed code
* '.Rmd' & '.Rpres': requirements from chunks (parsed using regular expressions to avoid dependency on knitr package). If rmarkdown package is installed, will also add requirements from custom output type.
* '.Rnw': tangles the document and then extracts from '.R' file.
1 | req_file(path)
|
path |
Path to file |
1 2 3 4 5 | path_r <- system.file("examples", "simple.R", package = "requirements")
path_rmd <- system.file("examples", "simple.Rmd", package = "requirements")
req_file(path_r)
req_file(path_rmd)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.