Description Usage Arguments Value Examples
Install (and optionally generate) required packages
1 2 3 4 | rip_install(requirements = "requirements.txt", packrat = FALSE,
dryrun = FALSE, verbose = dryrun, repo = options()$repo[1],
gen = !file.exists(requirements), inspect_files = c("R", "Rmd",
"Rpres", "lock"), path = dirname(requirements), ...)
|
requirements |
filename where requirements are stored |
packrat |
Should project be initialized with packrat? |
dryrun |
Flag if you just want to see what would happen if you ran the function |
verbose |
Flag to change verbosity |
repo |
What repository should be used to install packages? |
gen |
Should required packages be generated? |
inspect_files |
Character vector of file extensions to search for dependencies in. Officially supports the following extensions: 'c("R", "Rmd", "Rpres", "lock")'. Other extensions will be processed as if they were '.R' files. |
path |
Location where extensions from 'inspect_files' should be searched for. (see 'path' from '?list.files'). |
... |
Additional arguments to be passed to 'rip_freeze()' |
invisible
1 2 3 4 | ## Not run:
requirements(dryrun = TRUE)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.